#!/usr/bin/env python3
# -*- coding:utf-8 -*-
################################################################
# Copyright 2026 Dong Zhaorui. All rights reserved.
# Author: Dong Zhaorui 847235539@qq.com
# Date  : 2026-03-25
################################################################

import os

urdf_dir = os.path.join(os.path.dirname(__file__), "urdf")
HEXARM_URDF_PATH_DICT = {
    # Archer L6Y
    "archer_l6y_empty": f"{urdf_dir}/archer_l6y/empty.urdf",
    "archer_l6y_gp100": f"{urdf_dir}/archer_l6y/gp100.urdf",
    "archer_l6y_gp100_handle": f"{urdf_dir}/archer_l6y/gp100_handle.urdf",
    "archer_l6y_gp100_p050": f"{urdf_dir}/archer_l6y/gp100_p050.urdf",
    "archer_l6y_gp100_p050_handle":
    f"{urdf_dir}/archer_l6y/gp100_p050_handle.urdf",

    # Archer D6Y
    "archer_d6y_empty": f"{urdf_dir}/archer_d6y/empty.urdf",
    "archer_d6y_gp80": f"{urdf_dir}/archer_d6y/gp80.urdf",
    "archer_d6y_gp100": f"{urdf_dir}/archer_d6y/gp100.urdf",
    "archer_d6y_gp100_handle": f"{urdf_dir}/archer_d6y/gp100_handle.urdf",
    "archer_d6y_gp100_p050": f"{urdf_dir}/archer_d6y/gp100_p050.urdf",
    "archer_d6y_gp100_p050_handle":
    f"{urdf_dir}/archer_d6y/gp100_p050_handle.urdf",

    # Archer Y6
    "archer_y6_empty": f"{urdf_dir}/archer_y6/empty.urdf",
    "archer_y6_gp80": f"{urdf_dir}/archer_y6/gp80.urdf",
    "archer_y6_gp80_p008": f"{urdf_dir}/archer_y6/gp80_p008.urdf",
    "archer_y6_gp80_p008_handle":
    f"{urdf_dir}/archer_y6/gp80_p008_handle.urdf",
    "archer_y6_gp100": f"{urdf_dir}/archer_y6/gp100.urdf",
    "archer_y6_gp100_handle": f"{urdf_dir}/archer_y6/gp100_handle.urdf",
    "archer_y6_gp100_p050": f"{urdf_dir}/archer_y6/gp100_p050.urdf",
    "archer_y6_gp100_p050_handle":
    f"{urdf_dir}/archer_y6/gp100_p050_handle.urdf",

    # Firefly Y6
    "firefly_y6_empty": f"{urdf_dir}/firefly_y6/empty.urdf",
    "firefly_y6_gp80": f"{urdf_dir}/firefly_y6/gp80.urdf",
}

__all__ = [
    # path
    "HEXARM_URDF_PATH_DICT",
]
